==> flutter_slick-3.4.13.tar.gz: lib/components/fields/number.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:provider/provider.dart';

class NumberField extends StatefulWidget {
  final int? initialValue;
  final FormFieldValidator<int>? validator;
  final TextInputAction? textInputAction;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final FocusNode? focusNode;
  final bool autofocus;
  final bool enabled;
  final String labelText;
  final void Function(int?) onChanged;

  const NumberField({
    super.key,
    this.initialValue,
    this.validator,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.focusNode,
    this.autofocus = false,
    this.enabled = true,
    required this.labelText,
    required this.onChanged,
  });

  @override
  State<NumberField> createState() => _NumberFieldState();
}

class _NumberFieldState extends State<NumberField> {
  int? _currentValue;
  late FocusNode focusNode;

  @override
  void initState() {
    super.initState();
    _currentValue = widget.initialValue;
    focusNode = widget.focusNode ?? FocusNode();
    focusNode.addListener(() {
      if (focusNode.hasFocus) return;
      if (_currentValue != widget.initialValue) {
        Provider.of<NavigationLogic>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    var validator = widget.validator;
    return TextFormField(
      initialValue: widget.initialValue?.toString() ?? '',
      validator:
          validator == null ? null : (v) => validator(int.tryParse(v ?? '')),
      keyboardType: TextInputType.number,
      inputFormatters: [
        FilteringTextInputFormatter.digitsOnly,
      ],
      focusNode: focusNode,
      controller: widget.controller,
      autofocus: widget.autofocus,
      enabled: widget.enabled,
      onChanged: (v) {
        _currentValue = int.tryParse(v);
        widget.onChanged(_currentValue);
      },
      decoration: InputDecoration(
        enabled: widget.enabled,
        labelText: widget.labelText,
      ),
      onEditingComplete: widget.onEditingComplete,
      textInputAction: widget.textInputAction,
    );
  }
}

==> flutter_slick-3.6.1.tar.gz: lib/components/fields/number.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_slick/services/dirty_state_monitor.dart';
import 'package:provider/provider.dart';

class NumberField extends StatefulWidget {
  final int? initialValue;
  final FormFieldValidator<int>? validator;
  final TextInputAction? textInputAction;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final FocusNode? focusNode;
  final bool autofocus;
  final bool enabled;
  final String labelText;
  final void Function(int?) onChanged;

  const NumberField({
    super.key,
    this.initialValue,
    this.validator,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.focusNode,
    this.autofocus = false,
    this.enabled = true,
    required this.labelText,
    required this.onChanged,
  });

  @override
  State<NumberField> createState() => _NumberFieldState();
}

class _NumberFieldState extends State<NumberField> {
  int? _currentValue;
  late FocusNode focusNode;

  @override
  void initState() {
    super.initState();
    _currentValue = widget.initialValue;
    focusNode = widget.focusNode ?? FocusNode();
    focusNode.addListener(() {
      if (focusNode.hasFocus) return;
      if (_currentValue != widget.initialValue) {
        Provider.of<DirtyStateMonitor>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    var validator = widget.validator;
    return TextFormField(
      initialValue: widget.initialValue?.toString() ?? '',
      validator:
          validator == null ? null : (v) => validator(int.tryParse(v ?? '')),
      keyboardType: TextInputType.number,
      inputFormatters: [
        FilteringTextInputFormatter.digitsOnly,
      ],
      focusNode: focusNode,
      controller: widget.controller,
      autofocus: widget.autofocus,
      enabled: widget.enabled,
      onChanged: (v) {
        _currentValue = int.tryParse(v);
        widget.onChanged(_currentValue);
      },
      decoration: InputDecoration(
        enabled: widget.enabled,
        labelText: widget.labelText,
      ),
      onEditingComplete: widget.onEditingComplete,
      textInputAction: widget.textInputAction,
    );
  }
}
